@@ -3,17 +3,16 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to *.getInfo slices of the last.fm API
 
-our $VERSION = '0.0205';
+our $VERSION = '0.0206';
 
-use Moo;
 use strictures 2;
-use namespace::clean;
-
-use Carp;
-use Mojo::UserAgent;
+use Carp qw(croak);
+use Mojo::UserAgent ();
 use Mojo::JSON qw(decode_json);
-use Mojo::URL;
+use Mojo::URL ();
+use Moo;
 use Try::Tiny;
+use namespace::clean;
 
 
 has api_key => (
@@ -118,7 +117,7 @@ WebService::LastFM::TrackInfo - Access to *.getInfo slices of the last.fm API
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 SYNOPSIS
 
